aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorDan Albert <danalbert@google.com>2015-12-09 15:24:45 -0800
committerDan Albert <danalbert@google.com>2015-12-09 15:24:45 -0800
commit2477afdb6c497e363534d049d938dcf03cef28bc (patch)
treee057bec68b9c525efca0583ecf91d571e9595db5 /tests
parent542e194cf8193fe23570b314c2697568b00b99dd (diff)
downloadndk-2477afdb6c497e363534d049d938dcf03cef28bc.tar.gz
Add test support for x86 ASAN.
Bug: http://b/25981507 Change-Id: Id3b46ff76fe5aff8d3d605669affcc25c22731a4
Diffstat (limited to 'tests')
-rw-r--r--tests/device/asan-smoke/test_config.py8
-rw-r--r--tests/run-all.py4
2 files changed, 9 insertions, 3 deletions
diff --git a/tests/device/asan-smoke/test_config.py b/tests/device/asan-smoke/test_config.py
index a4408a71e..08ebee912 100644
--- a/tests/device/asan-smoke/test_config.py
+++ b/tests/device/asan-smoke/test_config.py
@@ -1,7 +1,13 @@
+def match_broken(abi, platform, device_platform, toolchain, subtest=None):
+ if abi == 'x86':
+ return abi, 'http://b/25981507'
+ return None, None
+
+
def match_unsupported(abi, platform, device_platform, toolchain, subtest=None):
if not toolchain.startswith('clang'):
return toolchain
- if not abi.startswith('armeabi'):
+ if not abi.startswith('armeabi') and not abi == 'x86':
return abi
if device_platform < 19:
return device_platform
diff --git a/tests/run-all.py b/tests/run-all.py
index 0201523f7..fd323886d 100644
--- a/tests/run-all.py
+++ b/tests/run-all.py
@@ -150,8 +150,8 @@ def check_adb_works_or_die(abi):
def can_use_asan(abi, api, toolchain):
- # ASAN is currently only supported for 32-bit ARM...
- if not abi.startswith('armeabi'):
+ # ASAN is currently only supported for 32-bit ARM and x86...
+ if not abi.startswith('armeabi') and not abi == 'x86':
return False
# On KitKat and newer...